@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2020  Johannes Pohl
+    Copyright (C) 2014-2024  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,43 +16,67 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***/
 
-#ifndef CLIENT_SETTINGS_HPP
-#define CLIENT_SETTINGS_HPP
-
-#include <string>
-#include <vector>
+#pragma once
 
+// local headers
+#include "common/sample_format.hpp"
 #include "player/pcm_device.hpp"
 
+// standard headers
+#include <string>
+
+
 
 struct ClientSettings
 {
-    struct ServerSettings
+    enum class SharingMode
+    {
+        unspecified,
+        exclusive,
+        shared
+    };
+
+    struct Mixer
+    {
+        enum class Mode
+        {
+            hardware,
+            software,
+            script,
+            none
+        };
+
+        Mode mode{Mode::software};
+        std::string parameter{""};
+    };
+
+    struct Server
     {
         std::string host{""};
         size_t port{1704};
     };
 
-    struct PlayerSettings
+    struct Player
     {
         std::string player_name{""};
+        std::string parameter{""};
         int latency{0};
-        PcmDevice pcm_device;
+        player::PcmDevice pcm_device;
         SampleFormat sample_format;
+        SharingMode sharing_mode{SharingMode::unspecified};
+        Mixer mixer;
     };
 
-    struct LoggingSettings
+    struct Logging
     {
-        bool debug{false};
-        std::string debug_logfile{""};
+        std::string sink{""};
+        std::string filter{"*:info"};
     };
 
     size_t instance{1};
     std::string host_id;
 
-    ServerSettings server;
-    PlayerSettings player;
-    LoggingSettings logging;
+    Server server;
+    Player player;
+    Logging logging;
 };
-
-#endif
