@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2023  Johannes Pohl
+    Copyright (C) 2014-2024  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,22 +27,27 @@
 // 3rd party headers
 
 // standard headers
-#include <mutex>
 
 namespace decoder
 {
 
+/// Base class for an audio decoder
 class Decoder
 {
 public:
-    Decoder(){};
+    /// c'tor
+    Decoder() = default;
+    /// d'tor
     virtual ~Decoder() = default;
 
+    /// decode encoded data stored in @p chunk, and write decoded data back into @p chunk
+    /// return true, if data could be decoded and written back into @p chunk
     virtual bool decode(msg::PcmChunk* chunk) = 0;
-    virtual SampleFormat setHeader(msg::CodecHeader* chunk) = 0;
 
-protected:
-    std::mutex mutex_;
+    /// Set the codec header, stored in @p chunk.
+    /// The CodecHeader is sent to every newly connected streaming client as first audio message.
+    /// @return the sampleformat, decoded from the header
+    virtual SampleFormat setHeader(msg::CodecHeader* chunk) = 0;
 };
 
 } // namespace decoder
