@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2020  Johannes Pohl
+    Copyright (C) 2014-2024  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,17 +16,23 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***/
 
+// prototype/interface header file
 #include "flac_decoder.hpp"
+
+// local headers
 #include "common/aixlog.hpp"
 #include "common/endian.hpp"
 #include "common/snap_exception.hpp"
-#include <cmath>
+
+// standard headers
 #include <cstring>
 #include <iostream>
 
 
 using namespace std;
 
+static constexpr auto LOG_TAG = "FlacDecoder";
+
 namespace decoder
 {
 
@@ -68,22 +74,22 @@ bool FlacDecoder::decode(msg::PcmChunk* chunk)
     std::lock_guard<std::mutex> lock(mutex_);
     cacheInfo_.reset();
     pcmChunk = chunk;
-    flacChunk->payload = (char*)realloc(flacChunk->payload, chunk->payloadSize);
+    flacChunk->payload = static_cast<char*>(realloc(flacChunk->payload, chunk->payloadSize));
     memcpy(flacChunk->payload, chunk->payload, chunk->payloadSize);
     flacChunk->payloadSize = chunk->payloadSize;
 
-    pcmChunk->payload = (char*)realloc(pcmChunk->payload, 0);
+    pcmChunk->payload = static_cast<char*>(realloc(pcmChunk->payload, 0));
     pcmChunk->payloadSize = 0;
     while (flacChunk->payloadSize > 0)
     {
-        if (!FLAC__stream_decoder_process_single(decoder))
+        if (FLAC__stream_decoder_process_single(decoder) == 0)
         {
             return false;
         }
 
         if (lastError_)
         {
-            LOG(ERROR) << "FLAC decode error: " << FLAC__StreamDecoderErrorStatusString[*lastError_] << "\n";
+            LOG(ERROR, LOG_TAG) << "FLAC decode error: " << FLAC__StreamDecoderErrorStatusString[*lastError_] << "\n";
             lastError_ = nullptr;
             return false;
         }
@@ -93,8 +99,8 @@ bool FlacDecoder::decode(msg::PcmChunk* chunk)
     {
         double diffMs = static_cast<double>(cacheInfo_.cachedBlocks_) / (static_cast<double>(cacheInfo_.sampleRate_) / 1000.);
         auto us = static_cast<uint64_t>(diffMs * 1000.);
-        tv diff(us / 1000000, us % 1000000);
-        LOG(DEBUG) << "Cached: " << cacheInfo_.cachedBlocks_ << ", " << diffMs << "ms, " << diff.sec << "s, " << diff.usec << "us\n";
+        tv diff(static_cast<int32_t>(us / 1000000), static_cast<int32_t>(us % 1000000));
+        LOG(TRACE, LOG_TAG) << "Cached: " << cacheInfo_.cachedBlocks_ << ", " << diffMs << "ms, " << diff.sec << "s, " << diff.usec << "us\n";
         chunk->timestamp = chunk->timestamp - diff;
     }
     return true;
@@ -144,8 +150,8 @@ FLAC__StreamDecoderReadStatus read_callback(const FLAC__StreamDecoder* /*decoder
 
         memcpy(buffer, flacChunk->payload, *bytes);
         memmove(flacChunk->payload, flacChunk->payload + *bytes, flacChunk->payloadSize - *bytes);
-        flacChunk->payloadSize = flacChunk->payloadSize - *bytes;
-        flacChunk->payload = (char*)realloc(flacChunk->payload, flacChunk->payloadSize);
+        flacChunk->payloadSize = flacChunk->payloadSize - static_cast<uint32_t>(*bytes);
+        flacChunk->payload = static_cast<char*>(realloc(flacChunk->payload, flacChunk->payloadSize));
     }
     return FLAC__STREAM_DECODER_READ_STATUS_CONTINUE;
 }
@@ -158,40 +164,40 @@ FLAC__StreamDecoderWriteStatus write_callback(const FLAC__StreamDecoder* /*decod
     {
         size_t bytes = frame->header.blocksize * sampleFormat.frameSize();
 
-        FlacDecoder* flacDecoder = static_cast<FlacDecoder*>(client_data);
+        auto* flacDecoder = static_cast<FlacDecoder*>(client_data);
         if (flacDecoder->cacheInfo_.isCachedChunk_)
             flacDecoder->cacheInfo_.cachedBlocks_ += frame->header.blocksize;
 
-        pcmChunk->payload = (char*)realloc(pcmChunk->payload, pcmChunk->payloadSize + bytes);
+        pcmChunk->payload = static_cast<char*>(realloc(pcmChunk->payload, pcmChunk->payloadSize + bytes));
 
         for (size_t channel = 0; channel < sampleFormat.channels(); ++channel)
         {
             if (buffer[channel] == nullptr)
             {
-                SLOG(ERROR) << "ERROR: buffer[" << channel << "] is NULL\n";
+                LOG(ERROR, LOG_TAG) << "ERROR: buffer[" << channel << "] is NULL\n";
                 return FLAC__STREAM_DECODER_WRITE_STATUS_ABORT;
             }
 
             if (sampleFormat.sampleSize() == 1)
             {
-                int8_t* chunkBuffer = (int8_t*)(pcmChunk->payload + pcmChunk->payloadSize);
+                auto* chunkBuffer = reinterpret_cast<int8_t*>(pcmChunk->payload + pcmChunk->payloadSize);
                 for (size_t i = 0; i < frame->header.blocksize; i++)
-                    chunkBuffer[sampleFormat.channels() * i + channel] = (int8_t)(buffer[channel][i]);
+                    chunkBuffer[sampleFormat.channels() * i + channel] = static_cast<int8_t>(buffer[channel][i]);
             }
             else if (sampleFormat.sampleSize() == 2)
             {
-                int16_t* chunkBuffer = (int16_t*)(pcmChunk->payload + pcmChunk->payloadSize);
+                auto* chunkBuffer = reinterpret_cast<int16_t*>(pcmChunk->payload + pcmChunk->payloadSize);
                 for (size_t i = 0; i < frame->header.blocksize; i++)
                     chunkBuffer[sampleFormat.channels() * i + channel] = SWAP_16((int16_t)(buffer[channel][i]));
             }
             else if (sampleFormat.sampleSize() == 4)
             {
-                int32_t* chunkBuffer = (int32_t*)(pcmChunk->payload + pcmChunk->payloadSize);
+                auto* chunkBuffer = reinterpret_cast<int32_t*>(pcmChunk->payload + pcmChunk->payloadSize);
                 for (size_t i = 0; i < frame->header.blocksize; i++)
                     chunkBuffer[sampleFormat.channels() * i + channel] = SWAP_32((int32_t)(buffer[channel][i]));
             }
         }
-        pcmChunk->payloadSize += bytes;
+        pcmChunk->payloadSize += static_cast<uint32_t>(bytes);
     }
 
     return FLAC__STREAM_DECODER_WRITE_STATUS_CONTINUE;
@@ -204,14 +210,15 @@ void metadata_callback(const FLAC__StreamDecoder* /*decoder*/, const FLAC__Strea
     if (metadata->type == FLAC__METADATA_TYPE_STREAMINFO)
     {
         static_cast<FlacDecoder*>(client_data)->cacheInfo_.sampleRate_ = metadata->data.stream_info.sample_rate;
-        sampleFormat.setFormat(metadata->data.stream_info.sample_rate, metadata->data.stream_info.bits_per_sample, metadata->data.stream_info.channels);
+        sampleFormat.setFormat(metadata->data.stream_info.sample_rate, static_cast<uint16_t>(metadata->data.stream_info.bits_per_sample),
+                               static_cast<uint16_t>(metadata->data.stream_info.channels));
     }
 }
 
 
 void error_callback(const FLAC__StreamDecoder* /*decoder*/, FLAC__StreamDecoderErrorStatus status, void* client_data)
 {
-    SLOG(ERROR) << "Got error callback: " << FLAC__StreamDecoderErrorStatusString[status] << "\n";
+    LOG(ERROR, LOG_TAG) << "Got error callback: " << FLAC__StreamDecoderErrorStatusString[status] << "\n";
     static_cast<FlacDecoder*>(client_data)->lastError_ = std::make_unique<FLAC__StreamDecoderErrorStatus>(status);
 }
 } // namespace callback
