@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2024  Johannes Pohl
+    Copyright (C) 2014-2025  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ static constexpr std::chrono::milliseconds BUFFER_TIME = 80ms;
 static constexpr int PERIODS = 4;
 static constexpr int MIN_PERIODS = 3;
 
-#define exp10(x) (exp((x)*log(10)))
+#define exp10(x) (exp((x) * log(10)))
 
 
 static constexpr auto LOG_TAG = "Alsa";
@@ -50,7 +50,7 @@ static constexpr auto DEFAULT_MIXER = "PCM";
 
 
 AlsaPlayer::AlsaPlayer(boost::asio::io_context& io_context, const ClientSettings::Player& settings, std::shared_ptr<Stream> stream)
-    : Player(io_context, settings, stream), handle_(nullptr), ctl_(nullptr), mixer_(nullptr), elem_(nullptr), sd_(io_context), timer_(io_context)
+    : Player(io_context, settings, std::move(stream)), handle_(nullptr), ctl_(nullptr), mixer_(nullptr), elem_(nullptr), sd_(io_context), timer_(io_context)
 {
     if (settings_.mixer.mode == ClientSettings::Mixer::Mode::hardware)
     {
@@ -93,7 +93,7 @@ AlsaPlayer::AlsaPlayer(boost::asio::io_context& io_context, const ClientSettings
 
 void AlsaPlayer::setHardwareVolume(const Volume& volume)
 {
-    std::lock_guard<std::recursive_mutex> lock(mutex_);
+    std::lock_guard<std::recursive_mutex> lock(rec_mutex_);
     if (elem_ == nullptr)
         return;
 
@@ -140,7 +140,7 @@ bool AlsaPlayer::getHardwareVolume(Volume& volume)
 {
     try
     {
-        std::lock_guard<std::recursive_mutex> lock(mutex_);
+        std::lock_guard<std::recursive_mutex> lock(rec_mutex_);
         if (elem_ == nullptr)
             throw SnapException("Mixer not initialized");
 
@@ -191,9 +191,8 @@ bool AlsaPlayer::getHardwareVolume(Volume& volume)
 
 void AlsaPlayer::waitForEvent()
 {
-    sd_.async_wait(boost::asio::posix::stream_descriptor::wait_read,
-                   [this](const boost::system::error_code& ec)
-                   {
+    sd_.async_wait(boost::asio::posix::stream_descriptor::wait_read, [this](const boost::system::error_code& ec)
+    {
         if (ec)
         {
             // TODO: fd is "Bad" after unplugging/plugging USB DAC, i.e. after init/uninit/init cycle
@@ -201,7 +200,7 @@ void AlsaPlayer::waitForEvent()
             return;
         }
 
-        std::lock_guard<std::recursive_mutex> lock(mutex_);
+        std::lock_guard<std::recursive_mutex> lock(rec_mutex_);
         if (ctl_ == nullptr)
             return;
 
@@ -226,9 +225,8 @@ void AlsaPlayer::waitForEvent()
                 // As workaround we defer getting the volume by 20ms.
                 timer_.cancel();
                 timer_.expires_after(20ms);
-                timer_.async_wait(
-                    [this](const boost::system::error_code& ec)
-                    {
+                timer_.async_wait([this](const boost::system::error_code& ec)
+                {
                     if (!ec)
                     {
                         if (getHardwareVolume(volume_))
@@ -250,15 +248,14 @@ void AlsaPlayer::initMixer()
         return;
 
     LOG(DEBUG, LOG_TAG) << "initMixer\n";
-    std::lock_guard<std::recursive_mutex> lock(mutex_);
+    std::lock_guard<std::recursive_mutex> lock(rec_mutex_);
     int err;
     if ((err = snd_ctl_open(&ctl_, mixer_device_.c_str(), SND_CTL_READONLY)) < 0)
         throw SnapException("Can't open control for " + mixer_device_ + ", error: " + snd_strerror(err));
     if ((err = snd_ctl_subscribe_events(ctl_, 1)) < 0)
         throw SnapException("Can't subscribe for events for " + mixer_device_ + ", error: " + snd_strerror(err));
-    fd_ = std::unique_ptr<pollfd, std::function<void(pollfd*)>>(new pollfd(),
-                                                                [](pollfd* p)
-                                                                {
+    fd_ = std::unique_ptr<pollfd, std::function<void(pollfd*)>>(new pollfd(), [](pollfd* p)
+    {
         close(p->fd);
         delete p;
     });
@@ -292,7 +289,7 @@ void AlsaPlayer::initMixer()
 
 void AlsaPlayer::initAlsa()
 {
-    std::lock_guard<std::recursive_mutex> lock(mutex_);
+    std::lock_guard<std::recursive_mutex> lock(rec_mutex_);
 
     const SampleFormat& format = stream_->getFormat();
     uint32_t rate = format.rate();
@@ -461,7 +458,7 @@ void AlsaPlayer::initAlsa()
 
 void AlsaPlayer::uninitAlsa(bool uninit_mixer)
 {
-    std::lock_guard<std::recursive_mutex> lock(mutex_);
+    std::lock_guard<std::recursive_mutex> lock(rec_mutex_);
     if (uninit_mixer)
         uninitMixer();
 
@@ -480,7 +477,7 @@ void AlsaPlayer::uninitMixer()
         return;
 
     LOG(DEBUG, LOG_TAG) << "uninitMixer\n";
-    std::lock_guard<std::recursive_mutex> lock(mutex_);
+    std::lock_guard<std::recursive_mutex> lock(rec_mutex_);
     if (sd_.is_open())
     {
         boost::system::error_code ec;
@@ -587,7 +584,7 @@ void AlsaPlayer::worker()
             }
             catch (const std::exception& e)
             {
-                LOG(ERROR, LOG_TAG) << "Exception in initAlsa: " << e.what() << endl;
+                LOG(ERROR, LOG_TAG) << "Exception in initAlsa: " << e.what() << "\n";
                 chronos::sleep(100);
             }
             if (handle_ == nullptr)
