@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2022  Johannes Pohl
+    Copyright (C) 2014-2024  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,8 +16,7 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***/
 
-#ifndef OBOE_PLAYER_HPP
-#define OBOE_PLAYER_HPP
+#pragma once
 
 // local headers
 #include "player.hpp"
@@ -27,6 +26,7 @@
 #include <oboe/Oboe.h>
 
 // standard headers
+#include <vector>
 
 
 namespace player
@@ -41,30 +41,37 @@ static constexpr auto OBOE = "oboe";
 class OboePlayer : public Player, public oboe::AudioStreamDataCallback, public oboe::AudioStreamErrorCallback
 {
 public:
+    /// c'tor
     OboePlayer(boost::asio::io_context& io_context, const ClientSettings::Player& settings, std::shared_ptr<Stream> stream);
+    /// d'tor
     virtual ~OboePlayer();
 
     void start() override;
     void stop() override;
 
 protected:
-    // AudioStreamDataCallback overrides
+    /// AudioStreamDataCallback::onAudioReady override
     oboe::DataCallbackResult onAudioReady(oboe::AudioStream* oboeStream, void* audioData, int32_t numFrames) override;
 
-    // AudioStreamErrorCallback overrides
+    /// AudioStreamErrorCallback::onErrorBeforeClose override
     void onErrorBeforeClose(oboe::AudioStream* oboeStream, oboe::Result error) override;
+    /// AudioStreamErrorCallback::onErrorAfterClose override
     void onErrorAfterClose(oboe::AudioStream* oboeStream, oboe::Result error) override;
 
 protected:
+    /// Open the oboe stream
     oboe::Result openStream();
+    /// Get current audio playout delay
     double getCurrentOutputLatencyMillis() const;
 
     bool needsThread() const override;
+    /// The oboe output stream
     std::shared_ptr<oboe::AudioStream> out_stream_;
+    /// Latency tuner to optimize the latency
+    std::unique_ptr<oboe::LatencyTuner> latency_tuner_;
 
-    std::unique_ptr<oboe::LatencyTuner> mLatencyTuner;
+    /// Audio data buffer used for chaning the bit depth
+    std::vector<char> audio_data_;
 };
 
 } // namespace player
-
-#endif
