@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2020  Johannes Pohl
+    Copyright (C) 2014-2022  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,11 +19,21 @@
 #ifndef OPEN_SL_PLAYER_HPP
 #define OPEN_SL_PLAYER_HPP
 
+// local headers
+#include "player.hpp"
+
+// 3rd party headers
 #include <SLES/OpenSLES.h>
 #include <SLES/OpenSLES_Android.h>
+
+// standard headers
 #include <string>
 
-#include "player.hpp"
+
+namespace player
+{
+
+static constexpr auto OPENSL = "opensl";
 
 typedef int (*AndroidAudioCallback)(short* buffer, int num_samples);
 
@@ -35,7 +45,7 @@ typedef int (*AndroidAudioCallback)(short* buffer, int num_samples);
 class OpenslPlayer : public Player
 {
 public:
-    OpenslPlayer(const PcmDevice& pcmDevice, std::shared_ptr<Stream> stream);
+    OpenslPlayer(boost::asio::io_context& io_context, const ClientSettings::Player& settings, std::shared_ptr<Stream> stream);
     virtual ~OpenslPlayer();
 
     void start() override;
@@ -47,7 +57,7 @@ protected:
     void initOpensl();
     void uninitOpensl();
 
-    void worker() override;
+    bool needsThread() const override;
     void throwUnsuccess(const std::string& phase, const std::string& what, SLresult result);
     std::string resultToString(SLresult result) const;
 
@@ -72,5 +82,6 @@ protected:
     std::shared_ptr<Stream> pubStream_;
 };
 
+} // namespace player
 
 #endif
