@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2020  Johannes Pohl
+    Copyright (C) 2014-2024  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,12 +16,26 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***/
 
+#ifndef NOMINMAX
+#define NOMINMAX
+#endif // NOMINMAX
+
+// prototype/interface header file
 #include "stream.hpp"
+
+// local headers
 #include "common/aixlog.hpp"
+#include "common/snap_exception.hpp"
+#include "common/str_compat.hpp"
 #include "time_provider.hpp"
+
+// 3rd party headers
+
+// standard headers
 #include <cmath>
+#include <cstring>
 #include <iostream>
-#include <string.h>
+
 
 using namespace std;
 namespace cs = chronos;
@@ -29,14 +43,16 @@ namespace cs = chronos;
 static constexpr auto LOG_TAG = "Stream";
 static constexpr auto kCorrectionBegin = 100us;
 
+// #define LOG_LATENCIES
 
 Stream::Stream(const SampleFormat& in_format, const SampleFormat& out_format)
     : in_format_(in_format), median_(0), shortMedian_(0), lastUpdate_(0), playedFrames_(0), correctAfterXFrames_(0), bufferMs_(cs::msec(500)), frame_delta_(0),
-      hard_sync_(true)
+      hard_sync_(true), time_cond_(1s)
 {
     buffer_.setSize(500);
     shortBuffer_.setSize(100);
     miniBuffer_.setSize(20);
+    latencies_.setSize(100);
 
     format_ = in_format_;
     if (out_format.isInitialized())
@@ -53,41 +69,7 @@ Stream::Stream(const SampleFormat& in_format, const SampleFormat& out_format)
     x = 1,000016667 / (1,000016667 - 1)
     */
     // setRealSampleRate(format_.rate());
-#ifdef HAS_SOXR
-    soxr_ = nullptr;
-    if ((format_.rate() != in_format_.rate()) || (format_.bits() != in_format_.bits()))
-    {
-        LOG(INFO, LOG_TAG) << "Resampling from " << in_format_.getFormat() << " to " << format_.getFormat() << "\n";
-        soxr_error_t error;
-
-        soxr_datatype_t in_type = SOXR_INT16_I;
-        soxr_datatype_t out_type = SOXR_INT16_I;
-        if (in_format_.sampleSize() > 2)
-            in_type = SOXR_INT32_I;
-        if (format_.sampleSize() > 2)
-            out_type = SOXR_INT32_I;
-        soxr_io_spec_t iospec = soxr_io_spec(in_type, out_type);
-        // HQ should be fine: http://sox.sourceforge.net/Docs/FAQ
-        soxr_quality_spec_t q_spec = soxr_quality_spec(SOXR_HQ, 0);
-        soxr_ = soxr_create(static_cast<double>(in_format_.rate()), static_cast<double>(format_.rate()), format_.channels(), &error, &iospec, &q_spec, NULL);
-        if (error)
-        {
-            LOG(ERROR, LOG_TAG) << "Error soxr_create: " << error << "\n";
-            soxr_ = nullptr;
-        }
-        // initialize the buffer with 20ms (~latency of the reampler)
-        resample_buffer_.resize(format_.frameSize() * ceil(format_.msRate()) * 20);
-    }
-#endif
-}
-
-
-Stream::~Stream()
-{
-#ifdef HAS_SOXR
-    if (soxr_)
-        soxr_delete(soxr_);
-#endif
+    resampler_ = std::make_unique<Resampler>(in_format_, format_);
 }
 
 
@@ -99,7 +81,7 @@ void Stream::setRealSampleRate(double sampleRate)
     }
     else
     {
-        correctAfterXFrames_ = round((format_.rate() / sampleRate) / (format_.rate() / sampleRate - 1.));
+        correctAfterXFrames_ = static_cast<int32_t>(round((format_.rate() / sampleRate) / (format_.rate() / sampleRate - 1.)));
         // LOG(TRACE, LOG_TAG) << "Correct after X: " << correctAfterXFrames_ << " (Real rate: " << sampleRate << ", rate: " << format_.rate() << ")\n";
     }
 }
@@ -107,13 +89,14 @@ void Stream::setRealSampleRate(double sampleRate)
 
 void Stream::setBufferLen(size_t bufferLenMs)
 {
-    bufferMs_ = cs::msec(bufferLenMs);
+    bufferMs_.store(cs::msec(bufferLenMs));
 }
 
 
 void Stream::clearChunks()
 {
-    while (chunks_.size() > 0)
+    std::lock_guard<std::mutex> lock(mutex_);
+    while (!chunks_.empty())
         chunks_.pop();
     resetBuffers();
 }
@@ -122,92 +105,28 @@ void Stream::clearChunks()
 void Stream::addChunk(unique_ptr<msg::PcmChunk> chunk)
 {
     // drop chunk if it's too old. Just in case, this shouldn't happen.
-    cs::usec age = std::chrono::duration_cast<cs::usec>(TimeProvider::serverNow() - chunk->start());
-    if (age > 5s + bufferMs_)
+    auto age = std::chrono::duration_cast<cs::msec>(TimeProvider::serverNow() - chunk->start());
+    if (age > 5s + bufferMs_.load())
         return;
 
-        // LOG(DEBUG, LOG_TAG) << "new chunk: " << chunk->durationMs() << " ms, Chunks: " << chunks_.size() << "\n";
-
-#ifndef HAS_SOXR
-    chunks_.push(move(chunk));
-#else
-    if (soxr_ == nullptr)
+    auto resampled = resampler_->resample(std::move(chunk));
+    if (resampled)
     {
-        chunks_.push(move(chunk));
-    }
-    else
-    {
-        if (in_format_.bits() == 24)
+        std::lock_guard<std::mutex> lock(mutex_);
+        recent_ = resampled;
+        chunks_.push(resampled);
+
+        std::shared_ptr<msg::PcmChunk> front_;
+        while (chunks_.front_copy(front_))
         {
-            // sox expects 32 bit input, shift 8 bits left
-            int32_t* frames = (int32_t*)chunk->payload;
-            for (size_t n = 0; n < chunk->getSampleCount(); ++n)
-                frames[n] = frames[n] << 8;
-        }
-
-        size_t idone;
-        size_t odone;
-        auto resample_buffer_framesize = resample_buffer_.size() / format_.frameSize();
-        auto error = soxr_process(soxr_, chunk->payload, chunk->getFrameCount(), &idone, resample_buffer_.data(), resample_buffer_framesize, &odone);
-        if (error)
-        {
-            LOG(ERROR, LOG_TAG) << "Error soxr_process: " << error << "\n";
-        }
-        else
-        {
-            LOG(TRACE, LOG_TAG) << "Resample idone: " << idone << "/" << chunk->getFrameCount() << ", odone: " << odone << "/"
-                                << resample_buffer_.size() / format_.frameSize() << ", delay: " << soxr_delay(soxr_) << "\n";
-
-            // some data has been resampled (odone frames) and some is still in the pipe (soxr_delay frames)
-            if (odone > 0)
-            {
-                // get the resamples ts from the input ts
-                auto input_end_ts = chunk->start() + chunk->duration<std::chrono::microseconds>();
-                double resampled_ms = (odone + soxr_delay(soxr_)) / format_.msRate();
-                auto resampled_start = input_end_ts - std::chrono::microseconds(static_cast<int>(resampled_ms * 1000.));
-
-                auto resampled_chunk = new msg::PcmChunk(format_, 0);
-                auto us = chrono::duration_cast<chrono::microseconds>(resampled_start.time_since_epoch()).count();
-                resampled_chunk->timestamp.sec = us / 1000000;
-                resampled_chunk->timestamp.usec = us % 1000000;
-
-                // copy from the resample_buffer to the resampled chunk
-                resampled_chunk->payloadSize = odone * format_.frameSize();
-                resampled_chunk->payload = (char*)realloc(resampled_chunk->payload, resampled_chunk->payloadSize);
-                memcpy(resampled_chunk->payload, resample_buffer_.data(), resampled_chunk->payloadSize);
-
-                if (format_.bits() == 24)
-                {
-                    // sox has quantized to 32 bit, shift 8 bits right
-                    int32_t* frames = (int32_t*)resampled_chunk->payload;
-                    for (size_t n = 0; n < resampled_chunk->getSampleCount(); ++n)
-                    {
-                        // +128 to round to the nearest so that quantisation steps are distributed evenly
-                        frames[n] = (frames[n] + 128) >> 8;
-                        if (frames[n] > 0x7fffffff)
-                            frames[n] = 0x7fffffff;
-                    }
-                }
-                chunks_.push(shared_ptr<msg::PcmChunk>(resampled_chunk));
-
-                // check if the resample_buffer is large enough, or if soxr was using all available space
-                if (odone == resample_buffer_framesize)
-                {
-                    // buffer for resampled data too small, add space for 5ms
-                    resample_buffer_.resize(resample_buffer_.size() + format_.frameSize() * ceil(format_.msRate()) * 5);
-                    LOG(DEBUG, LOG_TAG) << "Resample buffer completely filled, adding space for 5ms; new buffer size: " << resample_buffer_.size()
-                                        << " bytes\n";
-                }
-
-                // //LOG(TRACE, LOG_TAG) << "ts: " << out->timestamp.sec << "s, " << out->timestamp.usec/1000.f << " ms, duration: " << odone / format_.msRate()
-                // << "\n";
-                // int64_t next_us = us + static_cast<int64_t>(odone / format_.msRate() * 1000);
-                // LOG(TRACE, LOG_TAG) << "ts: " << us << ", next: " << next_us << ", diff: " << next_us_ - us << "\n";
-                // next_us_ = next_us;
-            }
+            age = std::chrono::duration_cast<cs::msec>(TimeProvider::serverNow() - front_->start());
+            if ((age > 5s + bufferMs_.load()) && chunks_.try_pop(front_))
+                LOG(TRACE, LOG_TAG) << "Oldest chunk too old: " << age.count() << " ms, removing. Chunks in queue left: " << chunks_.size() << "\n";
+            else
+                break;
         }
     }
-#endif
+    // LOG(TRACE, LOG_TAG) << "new chunk: " << chunk->durationMs() << " ms, age: " << age.count() << " ms, Chunks: " << chunks_.size() << "\n";
 }
 
 
@@ -226,15 +145,15 @@ void Stream::getSilentPlayerChunk(void* outputBuffer, uint32_t frames) const
 cs::time_point_clk Stream::getNextPlayerChunk(void* outputBuffer, uint32_t frames)
 {
     if (!chunk_ && !chunks_.try_pop(chunk_))
-        throw 0;
+        throw SnapException("No chunks available, requested frames: " + cpt::to_string(frames));
 
     cs::time_point_clk tp = chunk_->start();
     uint32_t read = 0;
     while (read < frames)
     {
         read += chunk_->readFrames(static_cast<char*>(outputBuffer) + read * format_.frameSize(), frames - read);
-        if (chunk_->isEndOfChunk() && !chunks_.try_pop(chunk_))
-            throw 0;
+        if ((read < frames) && chunk_->isEndOfChunk() && !chunks_.try_pop(chunk_))
+            throw SnapException("Not enough frames available, requested frames: " + cpt::to_string(frames) + ", available: " + cpt::to_string(read));
     }
     return tp;
 }
@@ -242,10 +161,10 @@ cs::time_point_clk Stream::getNextPlayerChunk(void* outputBuffer, uint32_t frame
 
 cs::time_point_clk Stream::getNextPlayerChunk(void* outputBuffer, uint32_t frames, int32_t framesCorrection)
 {
-    if (framesCorrection < 0 && frames + framesCorrection <= 0)
+    if (framesCorrection < 0 && (static_cast<int32_t>(frames) + framesCorrection <= 0))
     {
         // Avoid underflow in new char[] constructor.
-        framesCorrection = -frames + 1;
+        framesCorrection = -static_cast<int32_t>(frames) + 1;
     }
 
     if (framesCorrection == 0)
@@ -270,7 +189,7 @@ cs::time_point_clk Stream::getNextPlayerChunk(void* outputBuffer, uint32_t frame
         slices = max;
     }
     // Size of each slice. The last slice may be bigger.
-    int size = max / slices;
+    auto size = max / slices;
 
     // LOG(TRACE, LOG_TAG) << "getNextPlayerChunk, frames: " << frames << ", correction: " << framesCorrection << " (" << toRead << "), slices: " << slices
     // << "\n";
@@ -290,6 +209,21 @@ cs::time_point_clk Stream::getNextPlayerChunk(void* outputBuffer, uint32_t frame
             memcpy(static_cast<char*>(outputBuffer) + pos * format_.frameSize(), read_buffer_.data() + (pos - n) * format_.frameSize(),
                    size * format_.frameSize());
         }
+        //    --      --
+        //   -  -    -  -
+        //  -    -  -    -
+        // -      --      -
+
+        //    --       --
+        //   -  -     -  -
+        //  -    --  -    -
+        // -       --      -
+
+        //    --       --
+        //   -  -     -  -
+        //  -    -_  -    -
+        // -       --      -
+
         else
         {
             // Read all input frames, but skip a frame per slice when writing to the output.
@@ -305,7 +239,7 @@ cs::time_point_clk Stream::getNextPlayerChunk(void* outputBuffer, uint32_t frame
 }
 
 
-void Stream::updateBuffers(int age)
+void Stream::updateBuffers(chronos::usec::rep age)
 {
     buffer_.add(age);
     miniBuffer_.add(age);
@@ -323,24 +257,36 @@ void Stream::resetBuffers()
 
 bool Stream::getPlayerChunk(void* outputBuffer, const cs::usec& outputBufferDacTime, uint32_t frames)
 {
-    if (outputBufferDacTime > bufferMs_)
+    if (outputBufferDacTime > bufferMs_.load())
     {
-        LOG(INFO, LOG_TAG) << "outputBufferDacTime > bufferMs: " << cs::duration<cs::msec>(outputBufferDacTime) << " > " << cs::duration<cs::msec>(bufferMs_)
-                           << "\n";
+        LOG(INFO, LOG_TAG) << "outputBufferDacTime > bufferMs: " << cs::duration<cs::msec>(outputBufferDacTime) << " > "
+                           << cs::duration<cs::msec>(bufferMs_.load()) << "\n";
         return false;
     }
 
+    std::lock_guard<std::mutex> lock(mutex_);
     time_t now = time(nullptr);
     if (!chunk_ && !chunks_.try_pop(chunk_))
     {
         if (now != lastUpdate_)
         {
             lastUpdate_ = now;
-            LOG(INFO, LOG_TAG) << "no chunks available\n";
+            LOG(INFO, LOG_TAG) << "No chunks available\n";
         }
         return false;
     }
 
+#ifdef LOG_LATENCIES
+    // calculate the estimated end to end latency
+    if (recent_)
+    {
+        cs::nsec req_chunk_duration = cs::nsec(static_cast<cs::nsec::rep>(frames / format_.nsRate()));
+        auto youngest = recent_->end() - req_chunk_duration;
+        cs::msec age = std::chrono::duration_cast<cs::msec>(TimeProvider::serverNow() - youngest + outputBufferDacTime);
+        latencies_.add(age.count());
+    }
+#endif
+
     /// we have a chunk
     /// age = chunk age (server now - rec time: some positive value) - buffer (e.g. 1000ms) + time to DAC
     /// age = 0 => play now
@@ -352,7 +298,7 @@ bool Stream::getPlayerChunk(void* outputBuffer, const cs::usec& outputBufferDacT
         if (hard_sync_)
         {
             cs::nsec req_chunk_duration = cs::nsec(static_cast<cs::nsec::rep>(frames / format_.nsRate()));
-            cs::usec age = std::chrono::duration_cast<cs::usec>(TimeProvider::serverNow() - chunk_->start()) - bufferMs_ + outputBufferDacTime;
+            cs::usec age = std::chrono::duration_cast<cs::usec>(TimeProvider::serverNow() - chunk_->start()) - bufferMs_.load() + outputBufferDacTime;
             // LOG(INFO, LOG_TAG) << "age: " << age.count() / 1000 << ", buffer: " <<
             // std::chrono::duration_cast<chrono::milliseconds>(req_chunk_duration).count() << "\n";
             if (age < -req_chunk_duration)
@@ -367,16 +313,23 @@ bool Stream::getPlayerChunk(void* outputBuffer, const cs::usec& outputBufferDacT
             {
                 if (age.count() > 0)
                 {
-                    LOG(DEBUG, LOG_TAG) << "age > 0: " << age.count() / 1000 << "ms\n";
+                    LOG(DEBUG, LOG_TAG) << "age > 0: " << age.count() / 1000 << "ms, dropping old chunks\n";
                     // age > 0: the top of the stream is too old. We must fast foward.
                     // delete the current chunk, it's too old. This will avoid an endless loop if there is no chunk in the queue.
                     chunk_ = nullptr;
                     while (chunks_.try_pop(chunk_))
                     {
-                        age = std::chrono::duration_cast<cs::usec>(TimeProvider::serverNow() - chunk_->start()) - bufferMs_ + outputBufferDacTime;
+                        age = std::chrono::duration_cast<cs::usec>(TimeProvider::serverNow() - chunk_->start()) - bufferMs_.load() + outputBufferDacTime;
                         LOG(DEBUG, LOG_TAG) << "age: " << age.count() / 1000 << ", requested chunk_duration: "
                                             << std::chrono::duration_cast<std::chrono::milliseconds>(req_chunk_duration).count()
                                             << ", duration: " << chunk_->duration<std::chrono::milliseconds>().count() << "\n";
+                        // check if the current chunk's end is older than age => can be player
+                        if ((age.count() > 0) && (age < chunk_->duration<cs::usec>()))
+                        {
+                            // fast forward by "age" to get in sync, i.e. age = 0
+                            chunk_->seek(static_cast<uint32_t>(chunk_->format.nsRate() * std::chrono::duration_cast<cs::nsec>(age).count()));
+                            age = 0s;
+                        }
                         if (age.count() <= 0)
                             break;
                     }
@@ -388,13 +341,16 @@ bool Stream::getPlayerChunk(void* outputBuffer, const cs::usec& outputBufferDacT
                     // e.g. age = -20ms (=> should be played in 20ms)
                     // and the current chunk duration is 50ms, so we need to play 20ms silence (as we don't have data)
                     // and can play 30ms of the stream
-                    uint32_t silent_frames = static_cast<size_t>(-chunk_->format.nsRate() * std::chrono::duration_cast<cs::nsec>(age).count());
+                    uint32_t silent_frames = static_cast<uint32_t>(-chunk_->format.nsRate() * std::chrono::duration_cast<cs::nsec>(age).count());
                     bool result = (silent_frames <= frames);
                     silent_frames = std::min(silent_frames, frames);
-                    LOG(DEBUG, LOG_TAG) << "Silent frames: " << silent_frames << ", frames: " << frames
-                                        << ", age: " << std::chrono::duration_cast<cs::usec>(age).count() / 1000. << "\n";
-                    getSilentPlayerChunk(outputBuffer, silent_frames);
-                    getNextPlayerChunk((char*)outputBuffer + (chunk_->format.frameSize() * silent_frames), frames - silent_frames);
+                    if (silent_frames > 0)
+                    {
+                        LOG(DEBUG, LOG_TAG) << "Silent frames: " << silent_frames << ", frames: " << frames
+                                            << ", age: " << std::chrono::duration_cast<cs::usec>(age).count() / 1000. << "\n";
+                        getSilentPlayerChunk(outputBuffer, silent_frames);
+                    }
+                    getNextPlayerChunk(static_cast<char*>(outputBuffer) + (chunk_->format.frameSize() * silent_frames), frames - silent_frames);
 
                     if (result)
                     {
@@ -413,15 +369,15 @@ bool Stream::getPlayerChunk(void* outputBuffer, const cs::usec& outputBufferDacT
         if (correctAfterXFrames_ != 0)
         {
             playedFrames_ += frames;
-            if (playedFrames_ >= (uint32_t)abs(correctAfterXFrames_))
+            if (playedFrames_ >= static_cast<uint32_t>(abs(correctAfterXFrames_)))
             {
                 framesCorrection = static_cast<int32_t>(playedFrames_) / correctAfterXFrames_;
                 playedFrames_ %= abs(correctAfterXFrames_);
             }
         }
 
-        cs::usec age = std::chrono::duration_cast<cs::usec>(TimeProvider::serverNow() - getNextPlayerChunk(outputBuffer, frames, framesCorrection) - bufferMs_ +
-                                                            outputBufferDacTime);
+        cs::usec age = std::chrono::duration_cast<cs::usec>(TimeProvider::serverNow() - getNextPlayerChunk(outputBuffer, frames, framesCorrection) -
+                                                            bufferMs_.load() + outputBufferDacTime);
 
         setRealSampleRate(format_.rate());
         // check if we need a hard sync
@@ -452,7 +408,7 @@ bool Stream::getPlayerChunk(void* outputBuffer, const cs::usec& outputBufferDacT
             auto miniMedian = miniBuffer_.median();
             if ((cs::usec(shortMedian_) > kCorrectionBegin) && (cs::usec(miniMedian) > cs::usec(50)) && (cs::usec(age) > cs::usec(50)))
             {
-                double rate = (shortMedian_ / 100) * 0.00005;
+                double rate = (shortMedian_ / 100.) * 0.00005;
                 rate = 1.0 - std::min(rate, 0.0005);
                 // LOG(INFO, LOG_TAG) << "Rate: " << rate << "\n";
                 // we are late (age > 0), this means we are not playing fast enough
@@ -461,7 +417,7 @@ bool Stream::getPlayerChunk(void* outputBuffer, const cs::usec& outputBufferDacT
             }
             else if ((cs::usec(shortMedian_) < -kCorrectionBegin) && (cs::usec(miniMedian) < -cs::usec(50)) && (cs::usec(age) < -cs::usec(50)))
             {
-                double rate = (-shortMedian_ / 100) * 0.00005;
+                double rate = (-shortMedian_ / 100.) * 0.00005;
                 rate = 1.0 + std::min(rate, 0.0005);
                 // LOG(INFO, LOG_TAG) << "Rate: " << rate << "\n";
                 // we are early (age > 0), this means we are playing too fast
@@ -472,22 +428,45 @@ bool Stream::getPlayerChunk(void* outputBuffer, const cs::usec& outputBufferDacT
 
         updateBuffers(age.count());
 
-        // print sync stats
+        // update median_ and shortMedian_ and print sync stats
         if (now != lastUpdate_)
         {
+            // log buffer stats
             lastUpdate_ = now;
             median_ = buffer_.median();
             shortMedian_ = shortBuffer_.median();
-            LOG(INFO, LOG_TAG) << "Chunk: " << age.count() / 100 << "\t" << miniBuffer_.median() / 100 << "\t" << shortMedian_ / 100 << "\t" << median_ / 100
-                               << "\t" << buffer_.size() << "\t" << cs::duration<cs::msec>(outputBufferDacTime) << "\t" << frame_delta_ << "\n";
+            LOG(DEBUG, "Stats") << "Chunk: " << age.count() / 100 << "\t" << miniBuffer_.median() / 100 << "\t" << shortMedian_ / 100 << "\t" << median_ / 100
+                                << "\t" << buffer_.size() << "\t" << cs::duration<cs::msec>(outputBufferDacTime) << "\t" << frame_delta_ << "\n";
             frame_delta_ = 0;
+
+#ifdef LOG_LATENCIES
+            // log latencies
+            std::array<uint8_t, 5> percents = {100, 99, 95, 50, 5};
+            auto percentiles = latencies_.percentiles(percents);
+            std::stringstream ss;
+            for (std::size_t n = 0; n < percents.size(); ++n)
+                ss << ((n > 0) ? ", " : "") << (int)percents[n] << "%: " << percentiles[n];
+            LOG(DEBUG, "Latency") << ss.str() << "\n";
+#endif
         }
         return (abs(cs::duration<cs::msec>(age)) < 500);
     }
-    catch (int e)
+    catch (const std::exception& e)
     {
-        LOG(INFO) << "Exception\n";
+        LOG(INFO, LOG_TAG) << "Exception: " << e.what() << "\n";
         hard_sync_ = true;
         return false;
     }
 }
+
+
+bool Stream::getPlayerChunkOrSilence(void* outputBuffer, const chronos::usec& outputBufferDacTime, uint32_t frames)
+{
+    bool result = getPlayerChunk(outputBuffer, outputBufferDacTime, frames);
+    if (!result)
+    {
+        LOG(DEBUG, LOG_TAG) << time_cond_ << "Failed to get chunk, returning silence\n";
+        getSilentPlayerChunk(outputBuffer, frames);
+    }
+    return result;
+}
