@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2020  Johannes Pohl
+    Copyright (C) 2014-2024  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,20 +16,27 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***/
 
-#ifndef STREAM_H
-#define STREAM_H
+#pragma once
 
-#include "common/queue.h"
+// local headers
+#include "common/message/pcm_chunk.hpp"
+#include "common/queue.hpp"
+#include "common/resampler.hpp"
 #include "common/sample_format.hpp"
+#include "common/utils/logging.hpp"
 #include "double_buffer.hpp"
-#include "message/message.hpp"
-#include "message/pcm_chunk.hpp"
-#include <deque>
-#include <memory>
+
+// 3rd party headers
 #ifdef HAS_SOXR
 #include <soxr.h>
 #endif
 
+// standard headers
+#include <atomic>
+#include <memory>
+
+
+
 /// Time synchronized audio stream
 /**
  * Queue with PCM data.
@@ -39,7 +46,7 @@ class Stream
 {
 public:
     Stream(const SampleFormat& in_format, const SampleFormat& out_format);
-    virtual ~Stream();
+    virtual ~Stream() = default;
 
     /// Adds PCM data to the queue
     void addChunk(std::unique_ptr<msg::PcmChunk> chunk);
@@ -47,8 +54,17 @@ public:
 
     /// Get PCM data, which will be played out in "outputBufferDacTime" time
     /// frame = (num_channels) * (1 sample in bytes) = (2 channels) * (2 bytes (16 bits) per sample) = 4 bytes (32 bits)
+    /// @param[out] outputBuffer the buffer to be filled with PCM data
+    /// @param outputBufferDacTime the duration until the PCM chunk will be audible
+    /// @param frames the number of requested frames to be copied into outputBuffer
+    /// @return true if a chunk was available and successfully copied to outputBuffer
     bool getPlayerChunk(void* outputBuffer, const chronos::usec& outputBufferDacTime, uint32_t frames);
 
+    /// Try to get a player chunk and fill the buffer with silence if it fails
+    /// @sa getPlayerChunk
+    /// @return true if a chunk was available and successfully copied to outputBuffer, else false and outputBuffer is filled with silence
+    bool getPlayerChunkOrSilence(void* outputBuffer, const chronos::usec& outputBufferDacTime, uint32_t frames);
+
     /// "Server buffer": playout latency, e.g. 1000ms
     void setBufferLen(size_t bufferLenMs);
 
@@ -60,7 +76,7 @@ public:
     bool waitForChunk(const std::chrono::milliseconds& timeout) const;
 
 private:
-    /// Request an audio chunk from the front of the stream. 
+    /// Request an audio chunk from the front of the stream.
     /// @param outputBuffer will be filled with the chunk
     /// @param frames the number of requested frames
     /// @return the timepoint when this chunk should be audible
@@ -69,10 +85,10 @@ private:
     /// Request an audio chunk from the front of the stream with a tempo adaption
     /// @param outputBuffer will be filled with the chunk
     /// @param frames the number of requested frames
-    /// @param framesCorrection number of frames that should be added or removed. 
+    /// @param framesCorrection number of frames that should be added or removed.
     ///        The function will allways return "frames" frames, but will fit "frames + framesCorrection" frames into "frames"
     ///        so if frames is 100 and framesCorrection is 2, 102 frames will be read from the stream and 2 frames will be removed.
-    ///        This makes us "fast-forward" by 2 frames, or if framesCorrection is -3, 97 frames will be read from the stream and 
+    ///        This makes us "fast-forward" by 2 frames, or if framesCorrection is -3, 97 frames will be read from the stream and
     ///        filled with 3 frames (simply by dublication), this makes us effectively slower
     /// @return the timepoint when this chunk should be audible
     chronos::time_point_clk getNextPlayerChunk(void* outputBuffer, uint32_t frames, int32_t framesCorrection);
@@ -82,7 +98,7 @@ private:
     /// @param frames the number of requested frames
     void getSilentPlayerChunk(void* outputBuffer, uint32_t frames) const;
 
-    void updateBuffers(int age);
+    void updateBuffers(chronos::usec::rep age);
     void resetBuffers();
     void setRealSampleRate(double sampleRate);
 
@@ -93,26 +109,30 @@ private:
     DoubleBuffer<chronos::usec::rep> miniBuffer_;
     DoubleBuffer<chronos::usec::rep> shortBuffer_;
     DoubleBuffer<chronos::usec::rep> buffer_;
+    /// current chunk (oldest, to be played)
     std::shared_ptr<msg::PcmChunk> chunk_;
+    /// most recent chunk (newly queued)
+    std::shared_ptr<msg::PcmChunk> recent_;
+    DoubleBuffer<chronos::msec::rep> latencies_;
 
-    int median_;
-    int shortMedian_;
+    chronos::usec::rep median_;
+    chronos::usec::rep shortMedian_;
     time_t lastUpdate_;
     uint32_t playedFrames_;
     int32_t correctAfterXFrames_;
-    chronos::msec bufferMs_;
+    std::atomic<chronos::msec> bufferMs_;
+
+    std::unique_ptr<Resampler> resampler_;
 
-#ifdef HAS_SOXR
-    soxr_t soxr_;
-#endif
     std::vector<char> resample_buffer_;
     std::vector<char> read_buffer_;
     int frame_delta_;
     // int64_t next_us_;
 
+    mutable std::mutex mutex_;
+
     bool hard_sync_;
+
+    /// Log "failed to get chunk" only once per second
+    utils::logging::TimeConditional time_cond_;
 };
-
-
-
-#endif
