@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2020  Johannes Pohl
+    Copyright (C) 2014-2024  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,13 +16,20 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***/
 
+// prototype/interface header file
 #include "time_provider.hpp"
+
+// local headers
 #include "common/aixlog.hpp"
 
+// standard headers
+#include <chrono>
+
+static constexpr auto LOG_TAG = "TimeProvider";
 
 TimeProvider::TimeProvider() : diffToServer_(0)
 {
-    diffBuffer_.setSize(100);
+    diffBuffer_.setSize(200);
 }
 
 
@@ -30,30 +37,32 @@ void TimeProvider::setDiff(const tv& c2s, const tv& s2c)
 {
     //	tv latency = c2s - s2c;
     //	double diff = (latency.sec * 1000. + latency.usec / 1000.) / 2.;
-    double diff = ((double)c2s.sec / 2. - (double)s2c.sec / 2.) * 1000. + ((double)c2s.usec / 2. - (double)s2c.usec / 2.) / 1000.;
+    double diff = (static_cast<double>(c2s.sec) / 2. - static_cast<double>(s2c.sec) / 2.) * 1000. +
+                  (static_cast<double>(c2s.usec) / 2. - static_cast<double>(s2c.usec) / 2.) / 1000.;
     setDiffToServer(diff);
 }
 
 
 void TimeProvider::setDiffToServer(double ms)
 {
-    static int32_t lastTimeSync = 0;
-    timeval now;
-    chronos::steadytimeofday(&now);
+    using namespace std::chrono_literals;
+    auto now = std::chrono::system_clock::now();
+    static auto lastTimeSync = now;
+    auto diff = chronos::abs(now - lastTimeSync);
 
     /// clear diffBuffer if last update is older than a minute
-    if (!diffBuffer_.empty() && (std::abs(now.tv_sec - lastTimeSync) > 60))
+    if (!diffBuffer_.empty() && (diff > 60s))
     {
-        LOG(INFO) << "Last time sync older than a minute. Clearing time buffer\n";
-        diffToServer_ = ms * 1000;
+        LOG(INFO, LOG_TAG) << "Last time sync older than a minute. Clearing time buffer\n";
+        diffToServer_ = static_cast<chronos::usec::rep>(ms * 1000);
         diffBuffer_.clear();
     }
-    lastTimeSync = now.tv_sec;
+    lastTimeSync = now;
 
-    diffBuffer_.add(ms * 1000);
+    diffBuffer_.add(static_cast<chronos::usec::rep>(ms * 1000));
     diffToServer_ = diffBuffer_.median();
-    // LOG(INFO) << "setDiffToServer: " << ms << ", diff: " << diffToServer_ / 1000000 << " s, " << (diffToServer_ / 1000) % 1000 << "." << diffToServer_ % 1000
-    // << " ms\n";
+    // LOG(INFO, LOG_TAG) << "setDiffToServer: " << ms << ", diff: " << diffToServer_ / 1000000 << " s, " << (diffToServer_ / 1000) % 1000 << "." <<
+    // diffToServer_ % 1000 << " ms\n";
 }
 
 /*
