@@ -3,11 +3,11 @@
     (  _ \ /  \(  _ \(  )
      ) __/(  O )) __// (_/\
     (__)   \__/(__)  \____/
-    version 1.2.90
+    version 1.3.0
     https://github.com/badaix/popl
 
     This file is part of popl (program options parser lib)
-    Copyright (C) 2015-2019 Johannes Pohl
+    Copyright (C) 2015-2021 Johannes Pohl
 
     This software may be modified and distributed under the terms
     of the MIT license.  See the LICENSE file for details.
@@ -33,12 +33,15 @@
 #include <sstream>
 #include <stdexcept>
 #include <vector>
+#ifdef WINDOWS
+#include <cctype>
+#endif
 
 
 namespace popl
 {
 
-#define POPL_VERSION "1.2.90"
+#define POPL_VERSION "1.3.0"
 
 
 /// Option's argument type
@@ -764,8 +767,10 @@ inline void Value<T>::update_reference()
 {
     if (this->assign_to_)
     {
-        if (this->is_set() || default_)
-            *this->assign_to_ = value();
+        if (!this->is_set() && default_)
+            *this->assign_to_ = *default_;
+        else if (this->is_set())
+            *this->assign_to_ = values_.back();
     }
 }
 
@@ -940,18 +945,21 @@ inline void OptionParser::parse(const std::string& ini_filename)
     std::ifstream file(ini_filename.c_str());
     std::string line;
 
-    auto trim = [](std::string& s) {
+    auto trim = [](std::string& s)
+    {
         s.erase(s.begin(), std::find_if(s.begin(), s.end(), [](int ch) { return !std::isspace(ch); }));
         s.erase(std::find_if(s.rbegin(), s.rend(), [](int ch) { return !std::isspace(ch); }).base(), s.end());
         return s;
     };
 
-    auto trim_copy = [trim](const std::string& s) {
+    auto trim_copy = [trim](const std::string& s)
+    {
         std::string copy(s);
         return trim(copy);
     };
 
-    auto split = [trim_copy](const std::string& s) -> std::pair<std::string, std::string> {
+    auto split = [trim_copy](const std::string& s) -> std::pair<std::string, std::string>
+    {
         size_t pos = s.find('=');
         if (pos == std::string::npos)
             return {"", ""};
@@ -980,8 +988,6 @@ inline void OptionParser::parse(const std::string& ini_filename)
         Option_ptr option = find_option(key);
         if (option && (option->attribute() == Attribute::inactive))
             option = nullptr;
-        // if (option && (option->argument_type() != Argument::required))
-        //    option = nullptr;
 
         if (option)
             option->parse(OptionName::long_name, key_value.second.c_str());
