@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2020  Johannes Pohl
+    Copyright (C) 2014-2024  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,17 +16,18 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***/
 
+
+// local headers
+#include "sample_format.hpp"
+#include "common/snap_exception.hpp"
+#include "common/str_compat.hpp"
+#include "common/utils/string_utils.hpp"
+
+// standard headers
 #include <iostream>
 #include <sstream>
 #include <vector>
 
-#include "common/aixlog.hpp"
-#include "common/snap_exception.hpp"
-#include "common/str_compat.hpp"
-#include "common/utils.hpp"
-#include "common/utils/string_utils.hpp"
-#include "sample_format.hpp"
-
 
 using namespace std;
 
@@ -43,13 +44,13 @@ SampleFormat::SampleFormat(const std::string& format)
 }
 
 
-SampleFormat::SampleFormat(uint32_t sampleRate, uint16_t bitsPerSample, uint16_t channelCount)
+SampleFormat::SampleFormat(uint32_t sampleRate, uint16_t bitsPerSample, uint16_t channels)
 {
-    setFormat(sampleRate, bitsPerSample, channelCount);
+    setFormat(sampleRate, bitsPerSample, channels);
 }
 
 
-string SampleFormat::getFormat() const
+string SampleFormat::toString() const
 {
     stringstream ss;
     ss << rate_ << ":" << bits_ << ":" << channels_;
@@ -62,7 +63,8 @@ void SampleFormat::setFormat(const std::string& format)
     std::vector<std::string> strs;
     strs = utils::string::split(format, ':');
     if (strs.size() == 3)
-        setFormat(strs[0] == "*" ? 0 : cpt::stoul(strs[0]), strs[1] == "*" ? 0 : cpt::stoul(strs[1]), strs[2] == "*" ? 0 : cpt::stoul(strs[2]));
+        setFormat(strs[0] == "*" ? 0 : cpt::stoul(strs[0]), strs[1] == "*" ? 0 : static_cast<uint16_t>(cpt::stoul(strs[1])),
+                  strs[2] == "*" ? 0 : static_cast<uint16_t>(cpt::stoul(strs[2])));
     else
         throw SnapException("sampleformat must be <rate>:<bits>:<channels>");
 }
