@@ -24,25 +24,21 @@
 #include "server_settings.hpp"
 
 // 3rd party headers
+#include <boost/asio/ip/tcp.hpp>
+#include <boost/asio/ssl.hpp>
 #include <boost/beast/core.hpp>
-
-#if defined(__GNUC__) && !defined(__clang__)
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wmaybe-uninitialized"
+#include <boost/beast/ssl.hpp>
 #include <boost/beast/websocket.hpp>
-#pragma GCC diagnostic pop
-#else
-#include <boost/beast/websocket.hpp>
-#endif
 
 // standard headers
 #include <deque>
-
-using boost::asio::ip::tcp;
+#include <optional>
 
 namespace beast = boost::beast; // from <boost/beast.hpp>
 namespace http = beast::http;   // from <boost/beast/http.hpp>
 
+using tcp_socket = boost::asio::ip::tcp::socket;
+using ssl_socket = boost::asio::ssl::stream<tcp_socket>;
 
 /// Endpoint for a connected control client.
 /**
@@ -53,8 +49,10 @@ namespace http = beast::http;   // from <boost/beast/http.hpp>
 class ControlSessionHttp : public ControlSession
 {
 public:
-    /// ctor. Received message from the client are passed to ControlMessageReceiver
-    ControlSessionHttp(ControlMessageReceiver* receiver, tcp::socket&& socket, const ServerSettings::Http& settings);
+    /// c'tor for ssl sockets. Received message from the client are passed to ControlMessageReceiver
+    ControlSessionHttp(ControlMessageReceiver* receiver, ssl_socket&& socket, const ServerSettings& settings);
+    /// c'tor for tcp sockets
+    ControlSessionHttp(ControlMessageReceiver* receiver, tcp_socket&& socket, const ServerSettings& settings);
     ~ControlSessionHttp() override;
     void start() override;
     void stop() override;
@@ -62,19 +60,21 @@ public:
     /// Sends a message to the client (asynchronous)
     void sendAsync(const std::string& message) override;
 
-protected:
-    // HTTP methods
+private:
+    /// HTTP on read callback
     void on_read(beast::error_code ec, std::size_t bytes_transferred);
+    /// HTTP on write callback
     void on_write(beast::error_code ec, std::size_t bytes, bool close);
 
+    /// Handle an incoming HTTP request
     template <class Body, class Allocator, class Send>
     void handle_request(http::request<Body, http::basic_fields<Allocator>>&& req, Send&& send);
 
     http::request<http::string_body> req_;
-
-protected:
-    tcp::socket socket_;
+    std::optional<tcp_socket> tcp_socket_;
+    std::optional<ssl_socket> ssl_socket_;
     beast::flat_buffer buffer_;
-    ServerSettings::Http settings_;
+    ServerSettings settings_;
     std::deque<std::string> messages_;
+    bool is_ssl_;
 };
