@@ -16,10 +16,12 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***/
 
-#ifndef PCM_ENCODER_H
-#define PCM_ENCODER_H
+#pragma once
+
+// local headers
 #include "encoder.hpp"
 
+
 namespace encoder
 {
 
@@ -27,7 +29,7 @@ class PcmEncoder : public Encoder
 {
 public:
     PcmEncoder(const std::string& codecOptions = "");
-    void encode(const msg::PcmChunk* chunk) override;
+    void encode(const msg::PcmChunk& chunk) override;
     std::string name() const override;
 
 protected:
@@ -35,5 +37,3 @@ protected:
 };
 
 } // namespace encoder
-
-#endif
